import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="global_utils_88",
    version="0.0.5",
    description="gUtils. Use it everywhere!",
    long_description=README,
    long_description_content_type="text/markdown",
    #url="https://github.com/realpython/reader",
    author="lorepieri",
    #author_email="office@realpython.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["global_utils"],
    include_package_data=True,
    install_requires=["pybase64", "datetime"],
    entry_points={
        "console_scripts": [
            "gutils_entrypoint_script=global_utils.__main__:main",
        ]
    },
)
